import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#metadata Pod#metadata}
     *
     * @stability stable
     */
    readonly metadata: PodMetadata[];
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#spec Pod#spec}
     *
     * @stability stable
     */
    readonly spec: PodSpec[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeouts Pod#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: PodTimeouts;
}
/**
 * @stability stable
 */
export interface PodMetadata {
    /**
     * An unstructured key value map stored with the pod that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#annotations Pod#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#generate_name Pod#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the pod.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#labels Pod#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the pod, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the pod must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreferenceMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight is in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#weight Pod#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * preference block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#preference Pod#preference}
     *
     * @stability stable
     */
    readonly preference: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecutionPreference[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to a set of values.
     *
     * Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Values is an array of string values.
     *
     * If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTermMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * node_selector_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_selector_term Pod#node_selector_term}
     *
     * @stability stable
     */
    readonly nodeSelectorTerm?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecutionNodeSelectorTerm[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityNodeAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#preferred_during_scheduling_ignored_during_execution Pod#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityNodeAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#required_during_scheduling_ignored_during_execution Pod#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityNodeAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_labels Pod#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespaces Pod#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_key Pod#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#label_selector Pod#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#weight Pod#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pod_affinity_term Pod#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_labels Pod#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespaces Pod#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_key Pod#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#label_selector Pod#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#preferred_during_scheduling_ignored_during_execution Pod#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#required_during_scheduling_ignored_during_execution Pod#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_labels Pod#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespaces Pod#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_key Pod#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#label_selector Pod#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTermLabelSelector[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution {
    /**
     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#weight Pod#weight}
     *
     * @stability stable
     */
    readonly weight: number;
    /**
     * pod_affinity_term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pod_affinity_term Pod#pod_affinity_term}
     *
     * @stability stable
     */
    readonly podAffinityTerm: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecutionPodAffinityTerm[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_labels Pod#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution {
    /**
     * namespaces specifies which namespaces the labelSelector applies to (matches against); null or empty list means 'this pod's namespace'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespaces Pod#namespaces}
     *
     * @stability stable
     */
    readonly namespaces?: string[];
    /**
     * empty topology key is interpreted by the scheduler as 'all topologies'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_key Pod#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#label_selector Pod#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecutionLabelSelector[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinityPodAntiAffinity {
    /**
     * preferred_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#preferred_during_scheduling_ignored_during_execution Pod#preferred_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly preferredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAntiAffinityPreferredDuringSchedulingIgnoredDuringExecution[];
    /**
     * required_during_scheduling_ignored_during_execution block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#required_during_scheduling_ignored_during_execution Pod#required_during_scheduling_ignored_during_execution}
     *
     * @stability stable
     */
    readonly requiredDuringSchedulingIgnoredDuringExecution?: PodSpecAffinityPodAntiAffinityRequiredDuringSchedulingIgnoredDuringExecution[];
}
/**
 * @stability stable
 */
export interface PodSpecAffinity {
    /**
     * node_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_affinity Pod#node_affinity}
     *
     * @stability stable
     */
    readonly nodeAffinity?: PodSpecAffinityNodeAffinity[];
    /**
     * pod_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pod_affinity Pod#pod_affinity}
     *
     * @stability stable
     */
    readonly podAffinity?: PodSpecAffinityPodAffinity[];
    /**
     * pod_anti_affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pod_anti_affinity Pod#pod_anti_affinity}
     *
     * @stability stable
     */
    readonly podAntiAffinity?: PodSpecAffinityPodAntiAffinity[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#api_version Pod#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_path Pod#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_name Pod#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#divisor Pod#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource Pod#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map_key_ref Pod#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: PodSpecContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_ref Pod#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: PodSpecContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource_field_ref Pod#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: PodSpecContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_key_ref Pod#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: PodSpecContainerEnvValueFromSecretKeyRef[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value_from Pod#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: PodSpecContainerEnvValueFrom[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#prefix Pod#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map_ref Pod#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: PodSpecContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_ref Pod#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: PodSpecContainerEnvFromSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecContainerLifecyclePostStartTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecContainerLifecyclePreStopTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#post_start Pod#post_start}
     *
     * @stability stable
     */
    readonly postStart?: PodSpecContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pre_stop Pod#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: PodSpecContainerLifecyclePreStop[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecContainerLivenessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecContainerLivenessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_port Pod#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_ip Pod#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_port Pod#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#protocol Pod#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecContainerReadinessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecContainerReadinessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#limits Pod#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#requests Pod#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface PodSpecContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#add Pod#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#drop Pod#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#level Pod#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#role Pod#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#type Pod#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#user Pod#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#allow_privilege_escalation Pod#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#privileged Pod#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only_root_filesystem Pod#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_group Pod#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_non_root Pod#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_user Pod#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#capabilities Pod#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: PodSpecContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#se_linux_options Pod#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSpecContainerSecurityContextSeLinuxOptions[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecContainerStartupProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecContainerStartupProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecContainerStartupProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mount_path Pod#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mount_propagation Pod#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#sub_path Pod#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#args Pod#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#image Pod#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#image_pull_policy Pod#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#stdin Pod#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#stdin_once Pod#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#termination_message_path Pod#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#termination_message_policy Pod#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tty Pod#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#working_dir Pod#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#env Pod#env}
     *
     * @stability stable
     */
    readonly env?: PodSpecContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#env_from Pod#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: PodSpecContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#lifecycle Pod#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: PodSpecContainerLifecycle[];
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#liveness_probe Pod#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: PodSpecContainerLivenessProbe[];
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: PodSpecContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#readiness_probe Pod#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: PodSpecContainerReadinessProbe[];
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resources Pod#resources}
     *
     * @stability stable
     */
    readonly resources?: PodSpecContainerResources[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#security_context Pod#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: PodSpecContainerSecurityContext[];
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#startup_probe Pod#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: PodSpecContainerStartupProbe[];
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_mount Pod#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: PodSpecContainerVolumeMount[];
}
/**
 * @stability stable
 */
export interface PodSpecDnsConfigOption {
    /**
     * Name of the option.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the option. Optional: Defaults to empty.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecDnsConfig {
    /**
     * A list of DNS name server IP addresses.
     *
     * This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#nameservers Pod#nameservers}
     *
     * @stability stable
     */
    readonly nameservers?: string[];
    /**
     * A list of DNS search domains for host-name lookup.
     *
     * This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#searches Pod#searches}
     *
     * @stability stable
     */
    readonly searches?: string[];
    /**
     * option block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#option Pod#option}
     *
     * @stability stable
     */
    readonly option?: PodSpecDnsConfigOption[];
}
/**
 * @stability stable
 */
export interface PodSpecHostAliases {
    /**
     * Hostnames for the IP address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#hostnames Pod#hostnames}
     *
     * @stability stable
     */
    readonly hostnames: string[];
    /**
     * IP address of the host file entry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#ip Pod#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
/**
 * @stability stable
 */
export interface PodSpecImagePullSecrets {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvValueFromConfigMapKeyRef {
    /**
     * The key to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the ConfigMap or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvValueFromFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#api_version Pod#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_path Pod#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvValueFromResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_name Pod#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#divisor Pod#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource Pod#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvValueFromSecretKeyRef {
    /**
     * The key of the secret to select from. Must be a valid secret key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Specify whether the Secret or its key must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvValueFrom {
    /**
     * config_map_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map_key_ref Pod#config_map_key_ref}
     *
     * @stability stable
     */
    readonly configMapKeyRef?: PodSpecInitContainerEnvValueFromConfigMapKeyRef[];
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_ref Pod#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: PodSpecInitContainerEnvValueFromFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource_field_ref Pod#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: PodSpecInitContainerEnvValueFromResourceFieldRef[];
    /**
     * secret_key_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_key_ref Pod#secret_key_ref}
     *
     * @stability stable
     */
    readonly secretKeyRef?: PodSpecInitContainerEnvValueFromSecretKeyRef[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnv {
    /**
     * Name of the environment variable. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables.
     *
     * If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
    /**
     * value_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value_from Pod#value_from}
     *
     * @stability stable
     */
    readonly valueFrom?: PodSpecInitContainerEnvValueFrom[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvFromConfigMapRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvFromSecretRef {
    /**
     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Specify whether the Secret must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerEnvFrom {
    /**
     * An optional identifer to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#prefix Pod#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map_ref Pod#config_map_ref}
     *
     * @stability stable
     */
    readonly configMapRef?: PodSpecInitContainerEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_ref Pod#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: PodSpecInitContainerEnvFromSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePostStartExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePostStartHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePostStartHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecInitContainerLifecyclePostStartHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePostStartTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePostStart {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecInitContainerLifecyclePostStartExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecInitContainerLifecyclePostStartHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecInitContainerLifecyclePostStartTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePreStopExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePreStopHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePreStopHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecInitContainerLifecyclePreStopHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePreStopTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecyclePreStop {
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecInitContainerLifecyclePreStopExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecInitContainerLifecyclePreStopHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecInitContainerLifecyclePreStopTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLifecycle {
    /**
     * post_start block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#post_start Pod#post_start}
     *
     * @stability stable
     */
    readonly postStart?: PodSpecInitContainerLifecyclePostStart[];
    /**
     * pre_stop block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pre_stop Pod#pre_stop}
     *
     * @stability stable
     */
    readonly preStop?: PodSpecInitContainerLifecyclePreStop[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLivenessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLivenessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLivenessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecInitContainerLivenessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLivenessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerLivenessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecInitContainerLivenessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecInitContainerLivenessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecInitContainerLivenessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerPort {
    /**
     * Number of port to expose on the pod's IP address.
     *
     * This must be a valid port number, 0 < x < 65536.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_port Pod#container_port}
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * What host IP to bind the external port to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_ip Pod#host_ip}
     *
     * @stability stable
     */
    readonly hostIp?: string;
    /**
     * Number of port to expose on the host.
     *
     * If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_port Pod#host_port}
     *
     * @stability stable
     */
    readonly hostPort?: number;
    /**
     * If specified, this must be an IANA_SVC_NAME and unique within the pod.
     *
     * Each named port in a pod must have a unique name. Name for the port that can be referred to by services
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol for port. Must be UDP or TCP. Defaults to "TCP".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#protocol Pod#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerReadinessProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerReadinessProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerReadinessProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecInitContainerReadinessProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerReadinessProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerReadinessProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecInitContainerReadinessProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecInitContainerReadinessProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecInitContainerReadinessProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerResources {
    /**
     * Describes the maximum amount of compute resources allowed. More info: http://kubernetes.io/docs/user-guide/compute-resources/.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#limits Pod#limits}
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-compute-resources-container/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#requests Pod#requests}
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerSecurityContextCapabilities {
    /**
     * Added capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#add Pod#add}
     *
     * @stability stable
     */
    readonly add?: string[];
    /**
     * Removed capabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#drop Pod#drop}
     *
     * @stability stable
     */
    readonly drop?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#level Pod#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#role Pod#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#type Pod#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#user Pod#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerSecurityContext {
    /**
     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.
     *
     * This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#allow_privilege_escalation Pod#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * Run container in privileged mode.
     *
     * Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#privileged Pod#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * Whether this container has a read-only root filesystem. Default is false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only_root_filesystem Pod#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_group Pod#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_non_root Pod#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_user Pod#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * capabilities block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#capabilities Pod#capabilities}
     *
     * @stability stable
     */
    readonly capabilities?: PodSpecInitContainerSecurityContextCapabilities[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#se_linux_options Pod#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSpecInitContainerSecurityContextSeLinuxOptions[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerStartupProbeExec {
    /**
     * Command is the command line to execute inside the container, the working directory for the command is root ('/') in the container's filesystem.
     *
     * The command is simply exec'd, it is not run inside a shell, so traditional shell instructions. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerStartupProbeHttpGetHttpHeader {
    /**
     * The header field name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The header field value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerStartupProbeHttpGet {
    /**
     * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host Pod#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path to access on the HTTP server.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Name or number of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Scheme to use for connecting to the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#scheme Pod#scheme}
     *
     * @stability stable
     */
    readonly scheme?: string;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_header Pod#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: PodSpecInitContainerStartupProbeHttpGetHttpHeader[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerStartupProbeTcpSocket {
    /**
     * Number or name of the port to access on the container.
     *
     * Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerStartupProbe {
    /**
     * Minimum consecutive failures for the probe to be considered failed after having succeeded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#failure_threshold Pod#failure_threshold}
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Number of seconds after the container has started before liveness probes are initiated. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#initial_delay_seconds Pod#initial_delay_seconds}
     *
     * @stability stable
     */
    readonly initialDelaySeconds?: number;
    /**
     * How often (in seconds) to perform the probe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#period_seconds Pod#period_seconds}
     *
     * @stability stable
     */
    readonly periodSeconds?: number;
    /**
     * Minimum consecutive successes for the probe to be considered successful after having failed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#success_threshold Pod#success_threshold}
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Number of seconds after which the probe times out. More info: http://kubernetes.io/docs/user-guide/pod-states#container-probes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#timeout_seconds Pod#timeout_seconds}
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#exec Pod#exec}
     *
     * @stability stable
     */
    readonly exec?: PodSpecInitContainerStartupProbeExec[];
    /**
     * http_get block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#http_get Pod#http_get}
     *
     * @stability stable
     */
    readonly httpGet?: PodSpecInitContainerStartupProbeHttpGet[];
    /**
     * tcp_socket block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tcp_socket Pod#tcp_socket}
     *
     * @stability stable
     */
    readonly tcpSocket?: PodSpecInitContainerStartupProbeTcpSocket[];
}
/**
 * @stability stable
 */
export interface PodSpecInitContainerVolumeMount {
    /**
     * Path within the container at which the volume should be mounted. Must not contain ':'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mount_path Pod#mount_path}
     *
     * @stability stable
     */
    readonly mountPath: string;
    /**
     * Mount propagation mode.
     *
     * mount_propagation determines how mounts are propagated from the host to container and the other way around. Valid values are None (default), HostToContainer and Bidirectional.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mount_propagation Pod#mount_propagation}
     *
     * @stability stable
     */
    readonly mountPropagation?: string;
    /**
     * This must match the Name of a Volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#sub_path Pod#sub_path}
     *
     * @stability stable
     */
    readonly subPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecInitContainer {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#args Pod#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/containers#containers-and-commands
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#command Pod#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name. More info: http://kubernetes.io/docs/user-guide/images.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#image Pod#image}
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * Image pull policy.
     *
     * One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/images#updating-images
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#image_pull_policy Pod#image_pull_policy}
     *
     * @stability stable
     */
    readonly imagePullPolicy?: string;
    /**
     * Name of the container specified as a DNS_LABEL.
     *
     * Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether this container should allocate a buffer for stdin in the container runtime.
     *
     * If this is not set, reads from stdin in the container will always result in EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#stdin Pod#stdin}
     *
     * @stability stable
     */
    readonly stdin?: boolean;
    /**
     * Whether the container runtime should close the stdin channel after it has been opened by a single attach.
     *
     * When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#stdin_once Pod#stdin_once}
     *
     * @stability stable
     */
    readonly stdinOnce?: boolean;
    /**
     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.
     *
     * Message written is intended to be brief final status, such as an assertion failure message. Defaults to /dev/termination-log. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#termination_message_path Pod#termination_message_path}
     *
     * @stability stable
     */
    readonly terminationMessagePath?: string;
    /**
     * Optional: Indicate how the termination message should be populated.
     *
     * File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#termination_message_policy Pod#termination_message_policy}
     *
     * @stability stable
     */
    readonly terminationMessagePolicy?: string;
    /**
     * Whether this container should allocate a TTY for itself.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#tty Pod#tty}
     *
     * @stability stable
     */
    readonly tty?: boolean;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#working_dir Pod#working_dir}
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#env Pod#env}
     *
     * @stability stable
     */
    readonly env?: PodSpecInitContainerEnv[];
    /**
     * env_from block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#env_from Pod#env_from}
     *
     * @stability stable
     */
    readonly envFrom?: PodSpecInitContainerEnvFrom[];
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#lifecycle Pod#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: PodSpecInitContainerLifecycle[];
    /**
     * liveness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#liveness_probe Pod#liveness_probe}
     *
     * @stability stable
     */
    readonly livenessProbe?: PodSpecInitContainerLivenessProbe[];
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#port Pod#port}
     *
     * @stability stable
     */
    readonly port?: PodSpecInitContainerPort[];
    /**
     * readiness_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#readiness_probe Pod#readiness_probe}
     *
     * @stability stable
     */
    readonly readinessProbe?: PodSpecInitContainerReadinessProbe[];
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resources Pod#resources}
     *
     * @stability stable
     */
    readonly resources?: PodSpecInitContainerResources[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#security_context Pod#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: PodSpecInitContainerSecurityContext[];
    /**
     * startup_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#startup_probe Pod#startup_probe}
     *
     * @stability stable
     */
    readonly startupProbe?: PodSpecInitContainerStartupProbe[];
    /**
     * volume_mount block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_mount Pod#volume_mount}
     *
     * @stability stable
     */
    readonly volumeMount?: PodSpecInitContainerVolumeMount[];
}
/**
 * @stability stable
 */
export interface PodSpecReadinessGate {
    /**
     * refers to a condition in the pod's condition list with matching type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#condition_type Pod#condition_type}
     *
     * @stability stable
     */
    readonly conditionType: string;
}
/**
 * @stability stable
 */
export interface PodSpecSecurityContextSeLinuxOptions {
    /**
     * Level is SELinux level label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#level Pod#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Role is a SELinux role label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#role Pod#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * Type is a SELinux type label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#type Pod#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * User is a SELinux user label that applies to the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#user Pod#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface PodSpecSecurityContextSysctl {
    /**
     * Name of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of a property to set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface PodSpecSecurityContext {
    /**
     * A special supplemental group that applies to all containers in a pod.
     *
     * Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod: 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw---- If unset, the Kubelet will not modify the ownership and permissions of any volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_group Pod#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup?: string;
    /**
     * The GID to run the entrypoint of the container process.
     *
     * Uses runtime default if unset. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_group Pod#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: string;
    /**
     * Indicates that the container must run as a non-root user.
     *
     * If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_non_root Pod#run_as_non_root}
     *
     * @stability stable
     */
    readonly runAsNonRoot?: boolean;
    /**
     * The UID to run the entrypoint of the container process.
     *
     * Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#run_as_user Pod#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser?: string;
    /**
     * A list of groups applied to the first process run in each container, in addition to the container's primary GID.
     *
     * If unspecified, no groups will be added to any container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#supplemental_groups Pod#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups?: number[];
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#se_linux_options Pod#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSpecSecurityContextSeLinuxOptions[];
    /**
     * sysctl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#sysctl Pod#sysctl}
     *
     * @stability stable
     */
    readonly sysctl?: PodSpecSecurityContextSysctl[];
}
/**
 * @stability stable
 */
export interface PodSpecToleration {
    /**
     * Effect indicates the taint effect to match.
     *
     * Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#effect Pod#effect}
     *
     * @stability stable
     */
    readonly effect?: string;
    /**
     * Key is the taint key that the toleration applies to.
     *
     * Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Operator represents a key's relationship to the value.
     *
     * Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.
     *
     * By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#toleration_seconds Pod#toleration_seconds}
     *
     * @stability stable
     */
    readonly tolerationSeconds?: string;
    /**
     * Value is the taint value the toleration matches to.
     *
     * If the operator is Exists, the value should be empty, otherwise just a regular string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#value Pod#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface PodSpecTopologySpreadConstraintLabelSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values. Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#operator Pod#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#values Pod#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodSpecTopologySpreadConstraintLabelSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_labels Pod#match_labels}
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#match_expressions Pod#match_expressions}
     *
     * @stability stable
     */
    readonly matchExpressions?: PodSpecTopologySpreadConstraintLabelSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodSpecTopologySpreadConstraint {
    /**
     * describes the degree to which pods may be unevenly distributed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#max_skew Pod#max_skew}
     *
     * @stability stable
     */
    readonly maxSkew?: number;
    /**
     * the key of node labels.
     *
     * Nodes that have a label with this key and identical values are considered to be in the same topology.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_key Pod#topology_key}
     *
     * @stability stable
     */
    readonly topologyKey?: string;
    /**
     * indicates how to deal with a pod if it doesn't satisfy the spread constraint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#when_unsatisfiable Pod#when_unsatisfiable}
     *
     * @stability stable
     */
    readonly whenUnsatisfiable?: string;
    /**
     * label_selector block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#label_selector Pod#label_selector}
     *
     * @stability stable
     */
    readonly labelSelector?: PodSpecTopologySpreadConstraintLabelSelector[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#partition Pod#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_id Pod#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#caching_mode Pod#caching_mode}
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#data_disk_uri Pod#data_disk_uri}
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#disk_name Pod#disk_name}
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk. Expected values: Shared, Dedicated, Managed. Defaults to Shared.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#kind Pod#kind}
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_name Pod#secret_name}
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_namespace Pod#secret_namespace}
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#share_name Pod#share_name}
     *
     * @stability stable
     */
    readonly shareName: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCephFsSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#monitors Pod#monitors}
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_file Pod#secret_file}
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#user Pod#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_ref Pod#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: PodSpecVolumeCephFsSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_id Pod#volume_id}
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeConfigMap {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#default_mode Pod#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeConfigMapItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCsiControllerExpandSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCsiControllerPublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCsiNodePublishSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCsiNodeStageSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeCsi {
    /**
     * the name of the volume driver to use. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#driver Pod#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true". If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_attributes Pod#volume_attributes}
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume. More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_handle Pod#volume_handle}
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#controller_expand_secret_ref Pod#controller_expand_secret_ref}
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: PodSpecVolumeCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#controller_publish_secret_ref Pod#controller_publish_secret_ref}
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: PodSpecVolumeCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_publish_secret_ref Pod#node_publish_secret_ref}
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: PodSpecVolumeCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_stage_secret_ref Pod#node_stage_secret_ref}
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: PodSpecVolumeCsiNodeStageSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#api_version Pod#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_path Pod#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_name Pod#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#divisor Pod#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource Pod#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeDownwardApiItems {
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_ref Pod#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef: PodSpecVolumeDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource_field_ref Pod#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: PodSpecVolumeDownwardApiItemsResourceFieldRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeDownwardApi {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#default_mode Pod#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeDownwardApiItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeEmptyDir {
    /**
     * What type of storage medium should back this directory.
     *
     * The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#medium Pod#medium}
     *
     * @stability stable
     */
    readonly medium?: string;
    /**
     * Total amount of local storage required for this EmptyDir volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#size_limit Pod#size_limit}
     *
     * @stability stable
     */
    readonly sizeLimit?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#lun Pod#lun}
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#target_ww_ns Pod#target_ww_ns}
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeFlexVolumeSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#driver Pod#driver}
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#options Pod#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false (read/write).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_ref Pod#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: PodSpecVolumeFlexVolumeSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#dataset_name Pod#dataset_name}
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset. This is unique identifier of a Flocker dataset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#dataset_uuid Pod#dataset_uuid}
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#partition Pod#partition}
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pd_name Pod#pd_name}
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeGitRepo {
    /**
     * Target directory name.
     *
     * Must not contain or start with '..'. If '.' is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#directory Pod#directory}
     *
     * @stability stable
     */
    readonly directory?: string;
    /**
     * Repository URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#repository Pod#repository}
     *
     * @stability stable
     */
    readonly repository?: string;
    /**
     * Commit hash for the specified revision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#revision Pod#revision}
     *
     * @stability stable
     */
    readonly revision?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#endpoints_name Pod#endpoints_name}
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeHostPath {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#hostpath.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume. Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#type Pod#type}
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#iqn Pod#iqn}
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport. Defaults to 'default' (tcp).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#iscsi_interface Pod#iscsi_interface}
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#lun Pod#lun}
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#target_portal Pod#target_portal}
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeLocal {
    /**
     * Path of the directory on the host. More info: http://kubernetes.io/docs/user-guide/volumes#local.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeNfs {
    /**
     * Path that is exported by the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions. Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server. More info: http://kubernetes.io/docs/user-guide/volumes#nfs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#server Pod#server}
     *
     * @stability stable
     */
    readonly server: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumePersistentVolumeClaim {
    /**
     * ClaimName is the name of a PersistentVolumeClaim in the same.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#claim_name Pod#claim_name}
     *
     * @stability stable
     */
    readonly claimName?: string;
    /**
     * Will force the ReadOnly setting in VolumeMounts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PodSpecVolumePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#pd_id Pod#pd_id}
     *
     * @stability stable
     */
    readonly pdId: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesConfigMapItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesConfigMap {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the ConfigMap or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeProjectedSourcesConfigMapItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItemsFieldRef {
    /**
     * Version of the schema the FieldPath is written in terms of, defaults to 'v1'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#api_version Pod#api_version}
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Path of the field to select in the specified API version.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_path Pod#field_path}
     *
     * @stability stable
     */
    readonly fieldPath?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container_name Pod#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#divisor Pod#divisor}.
     *
     * @stability stable
     */
    readonly divisor?: string;
    /**
     * Resource to select.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource Pod#resource}
     *
     * @stability stable
     */
    readonly resource: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesDownwardApiItems {
    /**
     * Mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * Path is the relative path name of the file to be created.
     *
     * Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#field_ref Pod#field_ref}
     *
     * @stability stable
     */
    readonly fieldRef?: PodSpecVolumeProjectedSourcesDownwardApiItemsFieldRef[];
    /**
     * resource_field_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#resource_field_ref Pod#resource_field_ref}
     *
     * @stability stable
     */
    readonly resourceFieldRef?: PodSpecVolumeProjectedSourcesDownwardApiItemsResourceFieldRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesDownwardApi {
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeProjectedSourcesDownwardApiItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesSecret {
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Optional: Specify whether the Secret or it's keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeProjectedSourcesSecretItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSourcesServiceAccountToken {
    /**
     * Audience is the intended audience of the token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#audience Pod#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * ExpirationSeconds is the expected duration of validity of the service account token.
     *
     * It defaults to 1 hour and must be at least 10 minutes (600 seconds).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#expiration_seconds Pod#expiration_seconds}
     *
     * @stability stable
     */
    readonly expirationSeconds?: number;
    /**
     * Path specifies a relative path to the mount point of the projected volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjectedSources {
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map Pod#config_map}
     *
     * @stability stable
     */
    readonly configMap?: PodSpecVolumeProjectedSourcesConfigMap[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#downward_api Pod#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: PodSpecVolumeProjectedSourcesDownwardApi[];
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret Pod#secret}
     *
     * @stability stable
     */
    readonly secret?: PodSpecVolumeProjectedSourcesSecret[];
    /**
     * service_account_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#service_account_token Pod#service_account_token}
     *
     * @stability stable
     */
    readonly serviceAccountToken?: PodSpecVolumeProjectedSourcesServiceAccountToken[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeProjected {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#default_mode Pod#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * sources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#sources Pod#sources}
     *
     * @stability stable
     */
    readonly sources: PodSpecVolumeProjectedSources[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#group Pod#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions. Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#registry Pod#registry}
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#user Pod#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume Pod#volume}
     *
     * @stability stable
     */
    readonly volume: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeRbdSecretRef {
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#namespace Pod#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeRbd {
    /**
     * A collection of Ceph monitors. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#ceph_monitors Pod#ceph_monitors}
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#keyring Pod#keyring}
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name. Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#rados_user Pod#rados_user}
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#rbd_image Pod#rbd_image}
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name. Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#rbd_pool Pod#rbd_pool}
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts. Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#read_only Pod#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_ref Pod#secret_ref}
     *
     * @stability stable
     */
    readonly secretRef?: PodSpecVolumeRbdSecretRef[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeSecretItems {
    /**
     * The key to project.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#key Pod#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Optional: mode bits to use on this file, must be a value between 0 and 0777.
     *
     * If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#mode Pod#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The relative path of the file to map the key to.
     *
     * May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#path Pod#path}
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolumeSecret {
    /**
     * Optional: mode bits to use on created files by default.
     *
     * Must be a value between 0 and 0777. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#default_mode Pod#default_mode}
     *
     * @stability stable
     */
    readonly defaultMode?: string;
    /**
     * Optional: Specify whether the Secret or its keys must be defined.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#optional Pod#optional}
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * Name of the secret in the pod's namespace to use. More info: http://kubernetes.io/docs/user-guide/volumes#secrets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret_name Pod#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * items block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#items Pod#items}
     *
     * @stability stable
     */
    readonly items?: PodSpecVolumeSecretItems[];
}
/**
 * @stability stable
 */
export interface PodSpecVolumeVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fs_type Pod#fs_type}
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume_path Pod#volume_path}
     *
     * @stability stable
     */
    readonly volumePath: string;
}
/**
 * @stability stable
 */
export interface PodSpecVolume {
    /**
     * Volume's name. Must be a DNS_LABEL and unique within the pod. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#name Pod#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * aws_elastic_block_store block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#aws_elastic_block_store Pod#aws_elastic_block_store}
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: PodSpecVolumeAwsElasticBlockStore[];
    /**
     * azure_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#azure_disk Pod#azure_disk}
     *
     * @stability stable
     */
    readonly azureDisk?: PodSpecVolumeAzureDisk[];
    /**
     * azure_file block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#azure_file Pod#azure_file}
     *
     * @stability stable
     */
    readonly azureFile?: PodSpecVolumeAzureFile[];
    /**
     * ceph_fs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#ceph_fs Pod#ceph_fs}
     *
     * @stability stable
     */
    readonly cephFs?: PodSpecVolumeCephFs[];
    /**
     * cinder block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#cinder Pod#cinder}
     *
     * @stability stable
     */
    readonly cinder?: PodSpecVolumeCinder[];
    /**
     * config_map block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#config_map Pod#config_map}
     *
     * @stability stable
     */
    readonly configMap?: PodSpecVolumeConfigMap[];
    /**
     * csi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#csi Pod#csi}
     *
     * @stability stable
     */
    readonly csi?: PodSpecVolumeCsi[];
    /**
     * downward_api block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#downward_api Pod#downward_api}
     *
     * @stability stable
     */
    readonly downwardApi?: PodSpecVolumeDownwardApi[];
    /**
     * empty_dir block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#empty_dir Pod#empty_dir}
     *
     * @stability stable
     */
    readonly emptyDir?: PodSpecVolumeEmptyDir[];
    /**
     * fc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#fc Pod#fc}
     *
     * @stability stable
     */
    readonly fc?: PodSpecVolumeFc[];
    /**
     * flex_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#flex_volume Pod#flex_volume}
     *
     * @stability stable
     */
    readonly flexVolume?: PodSpecVolumeFlexVolume[];
    /**
     * flocker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#flocker Pod#flocker}
     *
     * @stability stable
     */
    readonly flocker?: PodSpecVolumeFlocker[];
    /**
     * gce_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#gce_persistent_disk Pod#gce_persistent_disk}
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: PodSpecVolumeGcePersistentDisk[];
    /**
     * git_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#git_repo Pod#git_repo}
     *
     * @stability stable
     */
    readonly gitRepo?: PodSpecVolumeGitRepo[];
    /**
     * glusterfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#glusterfs Pod#glusterfs}
     *
     * @stability stable
     */
    readonly glusterfs?: PodSpecVolumeGlusterfs[];
    /**
     * host_path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_path Pod#host_path}
     *
     * @stability stable
     */
    readonly hostPath?: PodSpecVolumeHostPath[];
    /**
     * iscsi block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#iscsi Pod#iscsi}
     *
     * @stability stable
     */
    readonly iscsi?: PodSpecVolumeIscsi[];
    /**
     * local block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#local Pod#local}
     *
     * @stability stable
     */
    readonly local?: PodSpecVolumeLocal[];
    /**
     * nfs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#nfs Pod#nfs}
     *
     * @stability stable
     */
    readonly nfs?: PodSpecVolumeNfs[];
    /**
     * persistent_volume_claim block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#persistent_volume_claim Pod#persistent_volume_claim}
     *
     * @stability stable
     */
    readonly persistentVolumeClaim?: PodSpecVolumePersistentVolumeClaim[];
    /**
     * photon_persistent_disk block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#photon_persistent_disk Pod#photon_persistent_disk}
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: PodSpecVolumePhotonPersistentDisk[];
    /**
     * projected block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#projected Pod#projected}
     *
     * @stability stable
     */
    readonly projected?: PodSpecVolumeProjected[];
    /**
     * quobyte block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#quobyte Pod#quobyte}
     *
     * @stability stable
     */
    readonly quobyte?: PodSpecVolumeQuobyte[];
    /**
     * rbd block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#rbd Pod#rbd}
     *
     * @stability stable
     */
    readonly rbd?: PodSpecVolumeRbd[];
    /**
     * secret block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#secret Pod#secret}
     *
     * @stability stable
     */
    readonly secret?: PodSpecVolumeSecret[];
    /**
     * vsphere_volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#vsphere_volume Pod#vsphere_volume}
     *
     * @stability stable
     */
    readonly vsphereVolume?: PodSpecVolumeVsphereVolume[];
}
/**
 * @stability stable
 */
export interface PodSpec {
    /**
     * Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.
     *
     * Value must be a positive integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#active_deadline_seconds Pod#active_deadline_seconds}
     *
     * @stability stable
     */
    readonly activeDeadlineSeconds?: number;
    /**
     * AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#automount_service_account_token Pod#automount_service_account_token}
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * Set DNS policy for containers within the pod.
     *
     * Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. Optional: Defaults to 'ClusterFirst', see [Kubernetes reference](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#dns_policy Pod#dns_policy}
     *
     * @stability stable
     */
    readonly dnsPolicy?: string;
    /**
     * Enables generating environment variables for service discovery. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#enable_service_links Pod#enable_service_links}
     *
     * @stability stable
     */
    readonly enableServiceLinks?: boolean;
    /**
     * Use the host's ipc namespace. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_ipc Pod#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean;
    /**
     * Host networking requested for this pod.
     *
     * Use the host's network namespace. If this option is set, the ports that will be used must be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_network Pod#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean;
    /**
     * Use the host's pid namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_pid Pod#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean;
    /**
     * Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#hostname Pod#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * NodeName is a request to schedule this pod onto a specific node.
     *
     * If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_name Pod#node_name}
     *
     * @stability stable
     */
    readonly nodeName?: string;
    /**
     * NodeSelector is a selector which must be true for the pod to fit on a node.
     *
     * Selector which must match a node's labels for the pod to be scheduled on that node. More info: http://kubernetes.io/docs/user-guide/node-selection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#node_selector Pod#node_selector}
     *
     * @stability stable
     */
    readonly nodeSelector?: {
        [key: string]: string;
    };
    /**
     * If specified, indicates the pod's priority.
     *
     * "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#priority_class_name Pod#priority_class_name}
     *
     * @stability stable
     */
    readonly priorityClassName?: string;
    /**
     * Restart policy for all containers within the pod. One of Always, OnFailure, Never. More info: http://kubernetes.io/docs/user-guide/pod-states#restartpolicy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#restart_policy Pod#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: string;
    /**
     * ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: http://releases.k8s.io/HEAD/docs/design/service_accounts.md.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#service_account_name Pod#service_account_name}
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * Share a single process namespace between all of the containers in a pod.
     *
     * When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Defaults to false.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#share_process_namespace Pod#share_process_namespace}
     *
     * @stability stable
     */
    readonly shareProcessNamespace?: boolean;
    /**
     * If specified, the fully qualified Pod hostname will be "...svc.". If not specified, the pod will not have a domainname at all..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#subdomain Pod#subdomain}
     *
     * @stability stable
     */
    readonly subdomain?: string;
    /**
     * Optional duration in seconds the pod needs to terminate gracefully.
     *
     * May be decreased in delete request. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#termination_grace_period_seconds Pod#termination_grace_period_seconds}
     *
     * @stability stable
     */
    readonly terminationGracePeriodSeconds?: number;
    /**
     * affinity block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#affinity Pod#affinity}
     *
     * @stability stable
     */
    readonly affinity?: PodSpecAffinity[];
    /**
     * container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#container Pod#container}
     *
     * @stability stable
     */
    readonly container?: PodSpecContainer[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#dns_config Pod#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: PodSpecDnsConfig[];
    /**
     * host_aliases block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#host_aliases Pod#host_aliases}
     *
     * @stability stable
     */
    readonly hostAliases?: PodSpecHostAliases[];
    /**
     * image_pull_secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#image_pull_secrets Pod#image_pull_secrets}
     *
     * @stability stable
     */
    readonly imagePullSecrets?: PodSpecImagePullSecrets[];
    /**
     * init_container block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#init_container Pod#init_container}
     *
     * @stability stable
     */
    readonly initContainer?: PodSpecInitContainer[];
    /**
     * readiness_gate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#readiness_gate Pod#readiness_gate}
     *
     * @stability stable
     */
    readonly readinessGate?: PodSpecReadinessGate[];
    /**
     * security_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#security_context Pod#security_context}
     *
     * @stability stable
     */
    readonly securityContext?: PodSpecSecurityContext[];
    /**
     * toleration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#toleration Pod#toleration}
     *
     * @stability stable
     */
    readonly toleration?: PodSpecToleration[];
    /**
     * topology_spread_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#topology_spread_constraint Pod#topology_spread_constraint}
     *
     * @stability stable
     */
    readonly topologySpreadConstraint?: PodSpecTopologySpreadConstraint[];
    /**
     * volume block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#volume Pod#volume}
     *
     * @stability stable
     */
    readonly volume?: PodSpecVolume[];
}
/**
 * @stability stable
 */
export interface PodTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#create Pod#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html#delete Pod#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html kubernetes_pod}.
 *
 * @stability stable
 */
export declare class Pod extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/pod.html kubernetes_pod} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PodMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PodMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PodMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PodSpec[];
    /**
     * @stability stable
     */
    set spec(value: PodSpec[]);
    /**
     * @stability stable
     */
    get specInput(): PodSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PodTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PodTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PodTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
